/* This file is part of KWordQuiz
  Copyright (C) 2003-2007 Peter Hedlund <peter.hedlund@kdemail.net>

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License version 2 as published by the Free Software Foundation.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to
  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  Boston, MA 02110-1301, USA.
*/

#include "prefquiz.h"

#include <QCheckBox>

PrefQuiz::PrefQuiz(QWidget *parent) : QWidget(parent)
{
  setupUi(this);

  connect(kcfg_AutoFlip, &QAbstractButton::toggled, kcfg_FlipDelay, &QWidget::setEnabled);
  connect(kcfg_AutoFlip, &QAbstractButton::toggled, kcfg_KeepDiscard, &QWidget::setEnabled);

  kcfg_FlipDelay -> setEnabled(kcfg_AutoFlip->isChecked());
  kcfg_KeepDiscard->setEnabled(kcfg_AutoFlip->isChecked());
}
